==> deepin-fcitx5configtool-plugin_6.0.11.tar.xz: BUILD/src/dcc-fcitx5configtool/translations/fcitx5configtool_ml.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>AddonsPage</name>
    <message>
        <location filename="../qml/AddonsPage.qml" line="20"/>
        <source>Add-ons</source>
        <translation>ഇൻപുട്ട് മെതോഡുകൾ</translation>
    </message>
</context>
<context>
    <name>AdvancedSettingsModule</name>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="14"/>
        <source>Advanced Settings</source>
        <translation>പ്രഗത്ന സംവിധാനങ്ങൾ</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="40"/>
        <source>"Advanced Settings" is only valid for the input method that uses the system settings, if the input method has its own settings, its own settings shall prevail.</source>
        <translation>“പ്രഗത്ന സംവിധാനങ്ങൾ” എന്നത് സിസ്റ്റം സംവിധാനങ്ങൾ ഉപയോഗിക്കുന്ന ഇൻപുട്ട് മെതോഡിന് മാത്രമേ പ്രയോഗിക്കാവൂ, ഇൻപുട്ട് മെതോഡ് തന്റെ സ്വന്തം സംവിധാനങ്ങൾ ഉപയോഗിച്ചാൽ, അത് സ്വന്തം സംവിധാനങ്ങൾ പ്രയോഗിക്കുന്നതായിരിക്കും.</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="53"/>
        <source>Global Config</source>
        <translation>പൊതു സംവിധാനം</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="69"/>
        <source>Add-ons</source>
        <translation>ഇൻപുട്ട് മെതോഡുകൾ</translation>
    </message>
</context>
<context>
    <name>DetailConfigItem</name>
    <message>
        <location filename="../qml/DetailConfigItem.qml" line="150"/>
        <source>Please enter a new shortcut</source>
        <translation>നിലവിലെ ഷ൉ർട്ട്‌ക്യാട്ട് പുതിയതായി പ്രവർത്തിപ്പിക്കാൻ നിങ്ങൾ ഒരു പുതിയ ഷോർട്ട്‌ക്യാട്ട് പ്രവർത്തിപ്പിക്കുക.</translation>
    </message>
</context>
<context>
    <name>IMList</name>
    <message>
        <location filename="../qml/IMList.qml" line="152"/>
        <source>Move Up</source>
        <translation>മേൽക്കൂറിക്കെട്ടുക</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="160"/>
        <source>Move Down</source>
        <translation>കീഴേക്കെട്ടുക</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="168"/>
        <source>Settings</source>
        <translation>സംവിധാനങ്ങൾ</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="176"/>
        <source>Remove</source>
        <translation>നീക്കം ചെയ്യുക</translation>
    </message>
</context>
<context>
    <name>InputMethodsChooser</name>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="35"/>
        <source>Add input method</source>
        <translation>ഇൻപുട്ട് മെതോഡ് ചേർക്കുക</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="41"/>
        <source>Search</source>
        <translation>തിരയുക</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="109"/>
        <source>Find more in App Store</source>
        <translation>പ്രോഗ്രാം സ്റ്റോറിൽ കൂടുതൽ കണ്ടെത്തുക</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="129"/>
        <source>Cancel</source>
        <translation>റദ്ദാക്കുക</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="136"/>
        <source>Add</source>
        <translation>ചേർക്കുക</translation>
    </message>
</context>
<context>
    <name>ManageInputMethodsModule</name>
    <message>
        <location filename="../qml/ManageInputMethodsModule.qml" line="15"/>
        <source>Input method management</source>
        <translation>ഇൻപുട്ട് മെതോഡ് പ്രവർത്തനം</translation>
    </message>
    <message>
        <location filename="../qml/ManageInputMethodsModule.qml" line="33"/>
        <source>Add input method</source>
        <translation>ഇൻപുട്ട് മെതോഡ് ചേർക്കുക</translation>
    </message>
</context>
<context>
    <name>ShortcutsModule</name>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="34"/>
        <source>Shortcuts</source>
        <translation>ഷോർട്ട്‌ക്യാട്ടുകൾ</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="49"/>
        <source>Restore Defaults</source>
        <translation>പ്രതികരിക്കാനുള്ള പ്രാഥമിക മൂല്യങ്ങൾ പുനഃസ്ഥാപിക്കുക</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="101"/>
        <source>Scroll between input methods</source>
        <translation>ഇൻപുട്ട് മെതോഡുകൾ ഇടയിൽ സ്ക്രോൾ ചെയ്യുക</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="131"/>
        <source>Turn on or off input methods</source>
        <translation>ഇൻപുട്ട് മെതോഡുകൾ തുറക്കുക അല്ലെങ്കിൽ അടച്ചുവെക്കുക</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="135"/>
        <source>Please enter a new shortcut</source>
        <translation>നിലവിലെ ഷോർട്ട്‌ക്യാട് പുതിയതായി പ്രവർത്തിപ്പിക്കാൻ നിങ്ങൾ ഒരു പുതിയ ഷോർട്ട്‌ക്യാട് പ്രവർത്തിപ്പിക്കുക.</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="162"/>
        <source>It turns on or off the currently used input method.If no input method is being used or the first input method is not the keyboard, it switches between the first input method and the currently used keyboard/input method.</source>
        <translation>നിലവിലെ ഇൻപുട്ട് മെതോഡ് തുറക്കുക അല്ലെങ്കിൽ അടച്ചുവെക്കുക. ഇൻപുട്ട് മെതോഡ് ഉപയോഗിച്ചിട്ടില്ലെങ്കിൽ അല്ലെങ്കിൽ ആദ്യ ഇൻപുട്ട് മെതോഡ് കീബോർഡ് അല്ലാത്താൽ, ആദ്യ ഇൻപുട്ട് മെതോഡ് എന്നത് നിലവിലെ കീബോർഡ്/ഇൻപുട്ട് മെതോഡ് ഇടയിൽ മാറ്റുക.</translation>
    </message>
</context>
<context>
    <name>fcitx5configtool</name>
    <message>
        <location filename="../qml/fcitx5configtool.qml" line="8"/>
        <source>Input Methods</source>
        <translation>ഇൻപുട്ട് മെതോഡുകൾ</translation>
    </message>
    <message>
        <location filename="../qml/fcitx5configtool.qml" line="9"/>
        <source>Input method management, input method shortcuts, advanced settings</source>
        <translation>ഇൻപുട്ട് മെതോഡ് പ്രവർത്തനം, ഇൻപുട്ട് മെതോഡ് ഷോർട്ട്‌ക്യാട്ടുകൾ, പ്രഗത്ന സംവിധാനങ്ങൾ</translation>
    </message>
</context>
</TS>

==> deepin-fcitx5configtool-plugin_6.0.12.tar.xz: BUILD/src/dcc-fcitx5configtool/translations/fcitx5configtool_ml.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ml">
<context>
    <name>AddonsPage</name>
    <message>
        <location filename="../qml/AddonsPage.qml" line="20"/>
        <source>Add-ons</source>
        <translation>ഇൻപുട്ട് മെതോഡുകൾ</translation>
    </message>
</context>
<context>
    <name>AdvancedSettingsModule</name>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="14"/>
        <source>Advanced Settings</source>
        <translation>പ്രഗത്ന സംവിധാനങ്ങൾ</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="28"/>
        <source>&quot;Advanced Settings&quot; is only valid for the input method that uses the system settings, if the input method has its own settings, its own settings shall prevail.</source>
        <translation>“പ്രഗത്ന സംവിധാനങ്ങൾ” എന്നത് സിസ്റ്റം സംവിധാനങ്ങൾ ഉപയോഗിക്കുന്ന ഇൻപുട്ട് മെതോഡിന് മാത്രമേ പ്രയോഗിക്കാവൂ, ഇൻപുട്ട് മെതോഡ് തന്റെ സ്വന്തം സംവിധാനങ്ങൾ ഉപയോഗിച്ചാൽ, അത് സ്വന്തം സംവിധാനങ്ങൾ പ്രയോഗിക്കുന്നതായിരിക്കും.</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="41"/>
        <source>Global Config</source>
        <translation>പൊതു സംവിധാനം</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="52"/>
        <source>Add-ons</source>
        <translation>ഇൻപുട്ട് മെതോഡുകൾ</translation>
    </message>
</context>
<context>
    <name>DetailConfigItem</name>
    <message>
        <location filename="../qml/DetailConfigItem.qml" line="126"/>
        <source>Please enter a new shortcut</source>
        <translation>നിലവിലെ ഷ൉ർട്ട്‌ക്യാട്ട് പുതിയതായി പ്രവർത്തിപ്പിക്കാൻ നിങ്ങൾ ഒരു പുതിയ ഷോർട്ട്‌ക്യാട്ട് പ്രവർത്തിപ്പിക്കുക.</translation>
    </message>
</context>
<context>
    <name>IMList</name>
    <message>
        <location filename="../qml/IMList.qml" line="54"/>
        <source>Move Up</source>
        <translation>മേൽക്കൂറിക്കെട്ടുക</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="61"/>
        <source>Move Down</source>
        <translation>കീഴേക്കെട്ടുക</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="69"/>
        <source>Settings</source>
        <translation>സംവിധാനങ്ങൾ</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="76"/>
        <source>Remove</source>
        <translation>നീക്കം ചെയ്യുക</translation>
    </message>
</context>
<context>
    <name>InputMethodsChooser</name>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="29"/>
        <source>Add input method</source>
        <translation>ഇൻപുട്ട് മെതോഡ് ചേർക്കുക</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="37"/>
        <source>Search</source>
        <translation>തിരയുക</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="102"/>
        <source>Find more in App Store</source>
        <translation>പ്രോഗ്രാം സ്റ്റോറിൽ കൂടുതൽ കണ്ടെത്തുക</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="121"/>
        <source>Cancel</source>
        <translation>റദ്ദാക്കുക</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="128"/>
        <source>Add</source>
        <translation>ചേർക്കുക</translation>
    </message>
</context>
<context>
    <name>ManageInputMethodsModule</name>
    <message>
        <location filename="../qml/ManageInputMethodsModule.qml" line="15"/>
        <source>Input method management</source>
        <translation>ഇൻപുട്ട് മെതോഡ് പ്രവർത്തനം</translation>
    </message>
    <message>
        <location filename="../qml/ManageInputMethodsModule.qml" line="29"/>
        <source>Add input method</source>
        <translation>ഇൻപുട്ട് മെതോഡ് ചേർക്കുക</translation>
    </message>
</context>
<context>
    <name>ShortcutsModule</name>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="34"/>
        <source>Shortcuts</source>
        <translation>ഷോർട്ട്‌ക്യാട്ടുകൾ</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="45"/>
        <source>Restore Defaults</source>
        <translation>പ്രതികരിക്കാനുള്ള പ്രാഥമിക മൂല്യങ്ങൾ പുനഃസ്ഥാപിക്കുക</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="97"/>
        <source>Scroll between input methods</source>
        <translation>ഇൻപുട്ട് മെതോഡുകൾ ഇടയിൽ സ്ക്രോൾ ചെയ്യുക</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="127"/>
        <source>Turn on or off input methods</source>
        <translation>ഇൻപുട്ട് മെതോഡുകൾ തുറക്കുക അല്ലെങ്കിൽ അടച്ചുവെക്കുക</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="131"/>
        <source>Please enter a new shortcut</source>
        <translation>നിലവിലെ ഷോർട്ട്‌ക്യാട് പുതിയതായി പ്രവർത്തിപ്പിക്കാൻ നിങ്ങൾ ഒരു പുതിയ ഷോർട്ട്‌ക്യാട് പ്രവർത്തിപ്പിക്കുക.</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="156"/>
        <source>It turns on or off the currently used input method.If no input method is being used or the first input method is not the keyboard, it switches between the first input method and the currently used keyboard/input method.</source>
        <translation>നിലവിലെ ഇൻപുട്ട് മെതോഡ് തുറക്കുക അല്ലെങ്കിൽ അടച്ചുവെക്കുക. ഇൻപുട്ട് മെതോഡ് ഉപയോഗിച്ചിട്ടില്ലെങ്കിൽ അല്ലെങ്കിൽ ആദ്യ ഇൻപുട്ട് മെതോഡ് കീബോർഡ് അല്ലാത്താൽ, ആദ്യ ഇൻപുട്ട് മെതോഡ് എന്നത് നിലവിലെ കീബോർഡ്/ഇൻപുട്ട് മെതോഡ് ഇടയിൽ മാറ്റുക.</translation>
    </message>
</context>
<context>
    <name>fcitx5configtool</name>
    <message>
        <location filename="../qml/fcitx5configtool.qml" line="8"/>
        <source>Input Methods</source>
        <translation>ഇൻപുട്ട് മെതോഡുകൾ</translation>
    </message>
    <message>
        <location filename="../qml/fcitx5configtool.qml" line="9"/>
        <source>Input method management, input method shortcuts, advanced settings</source>
        <translation>ഇൻപുട്ട് മെതോഡ് പ്രവർത്തനം, ഇൻപുട്ട് മെതോഡ് ഷോർട്ട്‌ക്യാട്ടുകൾ, പ്രഗത്ന സംവിധാനങ്ങൾ</translation>
    </message>
</context>
</TS>
